# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn23.03

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 23.03.1
Release: 100%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/v%{version}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit 8fd5f77cd84ea04667f987c7b84181604dc99f60
%define ovsshortcommit 8fd5f77

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%autosetup -n ovn-%{version} -a 10 -p 1

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Mon Mar 11 2024 Frode Nordahl <frode.nordahl@canonical.com> - 23.03.1-100
- controller: Set check_tnl_key for BFD on tunnel ifaces.
[Upstream: fec1ad85a29b714e42e2dac7e7290f3fb37895f7]

* Fri Mar 08 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-99
- tests: Skip EDNS test if the scapy version doesn't support it.
[Upstream: 907e4ef9ee04878946b2dfd99d7a682c18038295]

* Wed Mar 06 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-98
- northd: Don't skip the unSNAT stage for traffic towards VIPs.
[Upstream: f33155c7d9856b7803dd2e2f6beb729b9e2b5340]

* Thu Feb 29 2024 Ilya Maximets <i.maximets@ovn.org> - 23.03.1-97
- northd: Don't create fair Sb meters for ACLs with logging disabled.
[Upstream: 8c4995fc69772493e56d239c6c216ca5dbeb9f5f]

* Tue Feb 27 2024 Ilya Maximets <i.maximets@ovn.org> - 23.03.1-96
- controller: ofctrl: Use index for meter lookups.
[Upstream: 085377fa3358077b00f84efde061310ffeb2c56d]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-95
- tests: Fix "router port type update and then ...".
[Upstream: 1ad4d7425491409a1ce086011f7011f87e8ea5f1]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-94
- tests: Fix "ovn-controller - Chassis other_config".
[Upstream: 0314ffa2e20d640515ccbde192ea5472283347f1]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-93
- tests: Fix "ofctrl wait before clearing flows".
[Upstream: 677d4d8051e872f1fa2e387ae7b51d5d06ee2e76]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-92
- tests: Fix flaky "ovn-controller-vtep - binding 1".
[Upstream: b2afef4f7991c92eb1fa78b47de01984ce8b3764]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-91
- tests: Fix flaky "options:requested-chassis ...".
[Upstream: 080bf2844a85449206652126536aa09491e1ec5a]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-90
- tests: Fix typos in tests.
[Upstream: 95685640dbd468dd677ec91f9de3cd0a5cfccd30]

* Mon Feb 19 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-89
- tests: Have tests fail when adding veth peer fails.
[Upstream: 187d0d4fef2d0d78e68859f8443b5e0747fa6fcd]

* Mon Feb 12 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-88
- pinctrl: dns: Ignore additional records.
[Upstream: cb0c9185d027fec75d0bd4d454574e97ad894e56]

* Mon Feb 12 2024 Roberto Bartzen Acosta <roberto.acosta@luizalabs.com> - 23.03.1-87
- ovn-ic: Fix global blacklist filter for IPv6 addresses.
[Upstream: 6c15e96f0c2225117e07cbb664a29c0025fbb3a4]

* Mon Feb 12 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-86
- tests: Fix macro OVN_CHECK_PACKETS_CONTAIN.
[Upstream: d74c2ce0ab8fd6c2c5e1f24b116e273f7e14f5fe]

* Fri Feb 09 2024 Mark Michelson <mmichels@redhat.com> - 23.03.1-85
- features.c: Always wait on the rconn.
[Upstream: 5538fe723ce945c79b755497fbb931fe2dac63b5]

* Fri Feb 09 2024 Nobuhiro MIKI <nmiki@yahoo-corp.jp> - 23.03.1-84
- Documentation: Fix broken links in ovn-sandbox.rst.
[Upstream: 21956ff2a234541e4c22fc9094f5c588fa79daf5]

* Fri Feb 09 2024 Mark Michelson <mmichels@redhat.com> - 23.03.1-83
- ovn-sb.xml: Remove IPv4-only restriction from Service Monitors.
[Upstream: 1cd23bcfd2335e1cc58dd3d94ade9569b3fee760]

* Fri Feb 09 2024 Ilya Maximets <i.maximets@ovn.org> - 23.03.1-82
- github: Update versions of action dependencies (Node.js 20).
[Upstream: f97a7ba9498b683ece0aa13795828012dc9bb434]

* Thu Feb 08 2024 Ales Musil <amusil@redhat.com> - 23.03.1-81
- northd: Remove the protocol match from ECMP symmetric reply flows.
[Upstream: c4ae1857df373295009d4a00fb8458a970584e37]

* Tue Jan 30 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-80
- actions: Use random port selection for SNAT with external_port_range.
[Upstream: 09e6a814a40102e15b448600f867b2a15bbfa742]

* Tue Jan 30 2024 Mohammad Heib <mheib@redhat.com> - 23.03.1-79
- ovn-ic: Handle NB:name updates properly.
[Upstream: bea7dde2f54f4e70c524e9043e135516f56b7543]

* Thu Jan 25 2024 Aliasgar Ginwala <aginwala@ebay.com> - 23.03.1-78
- Fix segfault due to ssl-ciphers.
[Upstream: 591a0a2206c6e1db89a56b8ff13d565ed8b5dfef]

* Tue Jan 23 2024 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-77
- controller: fixed potential segfault when changing tunnel_key and deleting ls.
[Upstream: 7f1681b19d2865956c332bf7481a28ba4c89cd5f]

* Fri Jan 19 2024 Ales Musil <amusil@redhat.com> - 23.03.1-76
- northd: Use proper field for lookup_nd
[Upstream: 56a755211a856776d743484722ea2fc7b543150a]

* Wed Jan 17 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-75
- checkpatch.py: Port checkpatch related changes from the OVS repo.
[Upstream: 6be3e893d6125f4ec906270db57bfa0ff5bb30b2]

* Fri Jan 12 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-74
- actions: Make sure affinity learnt flows are auto deleted.
[Upstream: 5c4465f05ef42cdba809efd807f20b50473fa94e]

* Thu Jan 11 2024 Mark Michelson <mmichels@redhat.com> - 23.03.1-73
- pinctrl: Directly retrieve desired port_binding MAC.
[Upstream: 285564dc039c9f624a02d0acb39f33b799273519]

* Tue Jan 09 2024 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.03.1-72
- test: add dedicated test for garp-max-timeout
[Upstream: c513eb91c6c304de7a6c0de71a04cc75588e8fcf]

* Tue Jan 09 2024 Ales Musil <amusil@redhat.com> - 23.03.1-71
- treewide: Fix small memory leaks reported by static analysis
[Upstream: f1d37a3754d317ff0fdda308d91f24ffd34cc01e]

* Tue Jan 09 2024 Dumitru Ceara <dceara@redhat.com> - 23.03.1-70
- ovs: Bump submodule to include IDL "spurious delete" fix.
[Upstream: 32fd33320507c5089f8ef08f7a0cbb0ca0e1c484]

* Wed Jan 03 2024 Jacob Tanenbaum <jtanenba@redhat.com> - 23.03.1-69
- Correct ethtype referencing incorrect values
[Upstream: 6715365602bc9277692b55777ed52c234a5c1a21]

* Mon Dec 18 2023 Daniel Ding <danieldin186@gmail.com> - 23.03.1-68
- northd: forward arp request to lrp snat on.
[Upstream: 45dfd8be6a9d697b88f09cbbce720c5544ba443d]

* Fri Dec 08 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-67
- ovn-macros: Make sure stopped daemons continue before the test ends.
[Upstream: f38d6c0b524bf3e56af34b039ec6004290d039f1]

* Thu Dec 07 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-66
- system-test: Fix tcpdump usage in LB template tests.
[Upstream: 8abd0082b759d8cb63ca5774fca51f7b203b3ab7]

* Thu Dec 07 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.03.1-65
- controller: make garp_max_timeout configurable (#2087779)
[Upstream: 26a91f1ac38bf26636e69550d922642e39f9aa1b]

* Thu Dec 07 2023 Ales Musil <amusil@redhat.com> - 23.03.1-64
- system-tests: Consolidate wait condition in CoPP test
[Upstream: 01d85f351031a6125444eccf0e56eb0037d2741c]

* Thu Dec 07 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-63
- pinctrl: Fix up comments about sending RST packets for healthcheck.
[Upstream: 0865b78090523c8a1d7e2c7061ff3f6d3542432c]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-62
- fmt_pkt: make sure scapy-server is started once
[Upstream: 95d426d014f3129ad434d52bb5fd0e93a0df4bbd]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-61
- fmt_pkt: improve scapy-server logging
[Upstream: e939fb39aaee55923bb022ed4cdf2841ff79d709]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-60
- fmt_pkt: use -S check to wait for scapy sock file
[Upstream: 9b80a40efbabe89c5d09536416db30deadf11a96]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-59
- fmt_pkt: don't subshell when calling ovs-appctl
[Upstream: 233d59bffc4bca75ed50737f2fdb7f387fd06850]

* Mon Dec 04 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-58
- controller: fix group_table and meter_table allocation
[Upstream: 9a428e2b330f386b70eaced59ebd72c3569222c7]

* Fri Nov 24 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-57
- controller: avoid extra flows if localnet_learn_fdb is disabled
[Upstream: ee3dc050dd7d91ea94f081ac460a48d281f04855]

* Fri Nov 24 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-56
- controller: FDB entries for localnet should not overwrite entries for vifs (#2242830)
[Upstream: b76da8a790af1ff19640f976a21fc7033e1f20b9]

* Mon Nov 20 2023 Evgenii Kovalev <ekovalev.off@gmail.com> - 23.03.1-55
- pinctrl: reset success and failures n_count regardless of svc state
[Upstream: 378d608fa3858728b4d0a3b73ea4374f4b295cdc]

* Mon Nov 20 2023 Evgenii Kovalev <ekovalev.off@gmail.com> - 23.03.1-54
- pinctrl: send RST instead of RST_ACK bit for lb hc
[Upstream: 091fde815777a711dda830aa82c54da025af7177]

* Mon Nov 20 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-53
- controller: Don't artificially limit group and meter IDs to 16bit.
[Upstream: a497e552bec5935b97556b62bdd7303dab18fe76]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-52
- tests: fixed race_condition with max_prefix
[Upstream: e060ec3a8ec2850deec8a2d04d58bdd661cc7f2f]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-51
- tests: fixed "ovn-nbctl - daemon retry connection"
[Upstream: 740e0d2af4a254235b1c7786143b49f21c4e7603]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-50
- tests: fixed system test "LR with SNAT fragmentation needed for external server".
[Upstream: 07fa9051e9348953aa6fbd55548253b585bd46cb]

* Fri Nov 17 2023 martin.kalcok@canonical.com <martin.kalcok@canonical.com> - 23.03.1-49
- ovn-ctl man: Add election timer config to manpage
[Upstream: 95be07682f430b0b60236c78e06084042ec6d64c]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-48
- controller: have I+P assigning ct_zones for l3gateway ports
[Upstream: 6c15f7b7e654016b5f09292d90acb8b6183c61b5]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-47
- tests: fixed another set of flaky ovn-ic tests
[Upstream: 5479f0344174ee393541f4312fa0c2b3fad52146]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-46
- tests: wait for all flows to be installed before sending packets
[Upstream: 6a9ac409f01889bbd887241afc87fd4323dcc7a9]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-45
- tests: fixed "ipsec -- basic configuration"
[Upstream: dcc31854f8042fd99eb0de4eff6d704450371344]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-44
- tests: do not start backup-northd by default
[Upstream: 3f7845d4ef5adf40bcede5ae9f1e3ba1f4ef2458]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-43
- tests: fixed multiple tests not properly waiting for packets to be received
[Upstream: 38e73eb845c0e6d7b932c3697f7fbc3124435c31]

* Fri Nov 17 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-42
- ci: Pin Python, Fedora and Ubuntu runner versions.
[Upstream: ede9954ac921bfcb21e57f1c08f75c9a4ae380a9]

* Thu Nov 16 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-41
- ovs: Bump submodule to include E721 fixes.
[Upstream: b0d658bc66c3846f7f60dbdbf951e075ab8608d7]

* Thu Nov 16 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-40
- tests: Remove broken "feature inactivity probe" test.
[Upstream: a51ef9ba2ee2ff9c0f79e460bafe59989e8d292a]

* Wed Nov 15 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-39
- ovs: Bump submodule to v3.1.3. (#2164058)
[Upstream: 51e35c15f3a4e77e294770d5ff0b4d4c06777253]

* Wed Nov 15 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-38
- py-requirements: Remove hacking dependency and use recent flake8.
[Upstream: 9f3d494e62c9c83623139ea407018ca135c45f46]

* Fri Oct 20 2023 Ales Musil <amusil@redhat.com> - 23.03.1-37
- controller, northd: Wait for cleanup before replying to exit
[Upstream: 1f09eaa46f5579935c7c663cd82cd3eb5927a2dd]

* Fri Oct 20 2023 Mark Michelson <mmichels@redhat.com> - 23.03.1-36
- tests: Add missing check for scapy.
[Upstream: 6627389a6975c09800aaa80e12360b8b07ff4358]

* Wed Oct 18 2023 Ales Musil <amusil@redhat.com> - 23.03.1-35
- ci: Apply the ASAN workaround only for Clang <16
[Upstream: a43d6dc49f48c0c21b9d441422d115dc878e7b21]

* Wed Oct 18 2023 Ales Musil <amusil@redhat.com> - 23.03.1-34
- ci: Use proper uname argument to get the HW type
[Upstream: 72461e96242c713ce7d2787bf8931fa027b4578f]

* Thu Oct 12 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-33
- tests: Wait for new ovn-controllers to connect to Southbound.
[Upstream: 0213101be1261abf02334e32629ee25ae9b898b6]

* Tue Oct 10 2023 Ales Musil <amusil@redhat.com> - 23.03.1-32
- system-tests: Make sure that IPv6 address is available right away
[Upstream: e0923a6d282f144089382dea9451c89131135e09]

* Tue Oct 10 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-31
- Don't mention packet cloning when failing to find tunnel
[Upstream: e1657ff3ff4f1046e9ec3150cfadb6857ff6a2f4]

* Tue Oct 10 2023 Ales Musil <amusil@redhat.com> - 23.03.1-30
- northd: Allow need frag to be SNATed
[Upstream: c223dd86344988559f92470c667d25116a2be6e8]

* Tue Oct 10 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-29
- docs: require ovn-set-local-ip for co-located ovn-controllers
[Upstream: 8d5ca8b6d390899fb62d79dcda4f3fa225740a9b]

* Tue Oct 10 2023 Ilya Maximets <i.maximets@ovn.org> - 23.03.1-28
- memory-trim: Fix timestamp overflow warning right after reboot.
[Upstream: 658f8ef515e9a8d326d07b2303cf6a16a2c9ec63]

* Mon Oct 09 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-27
- Fix missing flows in ls_in_dhcp_options table
[Upstream: 7ef8a93748d21a190a3827ca98e001dba49ff754]

* Mon Oct 09 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-26
- controller: throttle port claim attempts from if-status
[Upstream: 7fad2584b4ec1b4d0d97d012c52b12acae16e246]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-25
- tests: fixed "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: 69b8d8baf28d4b27fd71d27cc974f1d14c4e87cc]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-24
- tests: move trim_zeros() to ovn-macros
[Upstream: 45b3946d6d05fd85db83d004f86ef4e04f00cb2f]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-23
- tests: fixed "L2 Drop and Allow ACL w/ Stateful ACL"
[Upstream: 6ec80d26a8110f781768c5880e15358a1b1d4336]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-22
- tests: fixed multiple tests missing ovn-nbctl "wait"
[Upstream: 7c0ed6716e3da21a4b71209900011389800576f1]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-21
- tests: fixed "options:requested-chassis for logical port"
[Upstream: 8aebd7bf916d324d7bc8b368d79a4ebe49e19bdd]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-20
- tests: fixed "Logical router policy packet marking"
[Upstream: 801ec2708248477e3513fb7fb8de131b4ccd5ac6]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.03.1-19
- tests: fixed multiple ovn-ic tests
[Upstream: 8115b60391815bea49d3ad5f78fbcad68aeed772]

* Thu Oct 05 2023 Ales Musil <amusil@redhat.com> - 23.03.1-18
- pinctrl: Reply with correct destination for ICMPv6 RA packets
[Upstream: 6a950fb4348f3de87ca7321189deacf5fbc0692a]

* Mon Oct 02 2023 Han Zhou <hzhou@ovn.org> - 23.03.1-17
- ovn-controller: Add monitor condition for FDB.
[Upstream: c5491c31bdf389ffcb426064fd52b0c84428a3d4]

* Thu Sep 21 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-16
- Rename scapy-server into scapy-server.py
[Upstream: 24c505ef7a0fc60461aaa515397595c637705711]

* Wed Sep 20 2023 Patryk Diak <pdiak@redhat.com> - 23.03.1-15
- Add ovnkube-identity binary to the ovn-kubernetes Dockerfile
[Upstream: d522eaa26e9f270a92b3608f80688f66268ed583]

* Tue Sep 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-14
- tests: offload scapy transformations to a separate unixctl daemon
[Upstream: a811fd6cfe0517bcebfcff7feae175f99c27f4f5]

* Fri Sep 15 2023 Mark Michelson <mmichels@redhat.com> - 23.03.1-13
- Prepare for 23.03.3.
[Upstream: d1c3b730958253a28b08c8feb1d5fc2bf2b2d070]

* Fri Sep 15 2023 Mark Michelson <mmichels@redhat.com> - 23.03.1-12
- Set release date for 23.03.2.
[Upstream: 05d20a51032d65b6eed0c499cbb56ddbde5c754d]

* Thu Sep 14 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.03.1-11
- northd: check if parent_name is set for tag_request 0
[Upstream: 22556693895e75bef262dbba48f5a5342be41822]

* Thu Sep 14 2023 Ales Musil <amusil@redhat.com> - 23.03.1-10
- ofctrl: Prevent conjunction duplication (#2175928)
[Upstream: 02d2cf035e278c873bb1c54bf22a08c15a68f566]

* Thu Sep 14 2023 Ales Musil <amusil@redhat.com> - 23.03.1-9
- ofctrl: Do not try to program long flows (#1955167)
[Upstream: a480ed99dba6a9ab533a466d5755426f128639ed]

* Mon Sep 11 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-8
- northd: Always ct commit ECMP symmetric traffic in the original direction.
[Upstream: 724cac380ad21e6d58461ad6a656fa17985ceebf]

* Wed Sep 06 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.03.1-7
- Use correct nw_ttl=255 to match against legit NAs
[Upstream: 9dc56cf445e8e7d0518fd71f4bcfd99add8bb536]

* Wed Sep 06 2023 Dumitru Ceara <dceara@redhat.com> - 23.03.1-6
- checkpatch: Ignore yml files when checking line lengths.
[Upstream: 681bc898d79b1c713f547e92176be0b87ac0f63b]

* Wed Aug 30 2023 Ales Musil <amusil@redhat.com> - 23.03.1-5
- northd: Make sure that skip_snat=true is evaluated before force_snat (#2224260)
[Upstream: ec2acfd4ace75158770f2d417e125acd333ecb4e]

* Tue Aug 29 2023 Mark Michelson <mmichels@redhat.com> - 23.03.1-4
- Prepare for 23.03.2.
[Upstream: bed973da0d44a6228598e173e8760000e437eebd]

